@@ -137,6 +137,9 @@ class QcloudApi(object):
         elif module == 'ccr':
             from .modules.ccr import Ccr
             service = Ccr(config)
+        elif module == 'dc':
+            from .modules.dc import Dc
+            service = Dc(config)
         else:
             raise ValueError('module not exists')
 
